import {Component, EventEmitter, Event, h, Prop, State} from '@stencil/core';
import {MonobankDropdownListInterface, MonobankMobileMenuListItemsInterface} from "../../../../../../../../index";

@Component({
  tag: 's-cnt-monobank-mobile-menu-items',
  styleUrl: 's-cnt-monobank-mobile-menu-items.css',
  shadow: false,
  scoped: true,
})
export class SCntMonobankMobileMenuItems {
  /**
   * Пункты мобильного меню
   */
  @Prop() mobileMenuItems: MonobankMobileMenuListItemsInterface;

  /**
   * Пункты выпадающего меню
   */
  @Prop() dropdownList: MonobankDropdownListInterface[];

  /**
   * Стейт для показа выпдадающего меню с картами
   */
  @State() dropdownCardToggleState: boolean = false;

  /**
   * Клик по пунктам мобильного меню
   */
  @Event() clickOnMobileMenuItem: EventEmitter;

  /**
   * Клик по пунктам мобильного меню
   */
  @Event() clickOnDropdownMenuItem: EventEmitter;

  /**
   * Реф иконки навигации
   */
  public navIconTag: HTMLElement;

  /**
   * Реф выпадающего меню
   */
  public dropdownListTag: HTMLElement;

  render() {
    return (
      <div>
        <a onClick={(item) => this.clickOnMobileMenuItemHandler(item)} class={this.mobileMenuItems.class} href={this.mobileMenuItems.link}>
          {this.mobileMenuItems.item}
          {this.mobileMenuItems.class && (
            <div class="nav-icon" ref={el => this.navIconTag = el}>
              <i class="fas fa-angle-down" />
            </div>
          )}
        </a>
        {this.mobileMenuItems.class && (
          <ul class="card-menu-dropdown-list" ref={el => this.dropdownListTag = el}>
            <CardMenuDropdownListFunctionalComponent
              clickOnDropdownMenuItemHandler={(item) => this.clickOnDropdownMenuItemHandler(item)}
              array={this.dropdownList}
            />
          </ul>
        )}
      </div>
    );
  }

  /**
   *
   */
  public clickOnMobileMenuItemHandler(item) {
    this.openDropdownList()
    this.clickOnMobileMenuItem.emit(item)
  }

  /**
   *
   */
  public clickOnDropdownMenuItemHandler(item) {
    this.clickOnDropdownMenuItem.emit(item)
  }

  /**
   * Клик пункту Карты
   */
  public openDropdownList() {
    this.dropdownCardToggleState = !this.dropdownCardToggleState;
    this.addOrRemoveClassForNavIcon();
    this.addOrRemoveClassForDropdown();
  }

  /**
   * Удаление и добавление класса иконки навигации
   */
  public addOrRemoveClassForNavIcon() {
    if (this.dropdownCardToggleState === true) {
      this.navIconTag.classList.add('active');
    } else {
      this.navIconTag.classList.remove('active');
    }
  }

  /**
   * Удаление и добавление класса для выпадающего меню
   */
  public addOrRemoveClassForDropdown() {
    if (this.dropdownCardToggleState === true) {
      this.dropdownListTag.classList.add('active');
    } else {
      this.dropdownListTag.classList.remove('active');
    }
  }
}


const CardMenuDropdownListFunctionalComponent = props => {
  return props.array.map(item => {
    return (
      <li>
        <a onClick={(event) => props.clickOnDropdownMenuItemHandler(event)}>
          <img class="card-icon" src={item.img} alt={item.item} />
          {item.item}
        </a>
      </li>
    );
  });
};
