import {Component, ComponentInterface, h, Prop, State, Event, EventEmitter} from '@stencil/core';
import {MonoBankAuthForm} from "./res/interface/common.interface";

@Component({
  tag: 's-monobank-auth-form',
  styleUrl: 's-monobank-auth-form.css',
  shadow: false,
  scoped: true
})
export class SMonobankAuthForm implements ComponentInterface {
  /**
   *
   */
  @Prop() logInForm: MonoBankAuthForm;

  /**
   *
   */
  @Prop() codeConfirmation: boolean;

  /**
   *
   */
  @State() inputWarning: boolean;

  /**
   *
   */
  @Event() sendNumber: EventEmitter;

  /**
   * ref
   */
  authLogin: HTMLInputElement

  /**
   * ref
   */
  authBtn: HTMLElement;

  render() {
    return (
      <form>
        <div class="auth-login-form-title">
          {this.logInForm.formTitle}
        </div>
        <div class="auth-login-form-subtitle">
          {this.logInForm.formSubtitle}
        </div>
        <div class="auth-login-form-input-wrapper">
          {
            this.inputWarning ? (
              <span class='warning-error-input'>
                {this.logInForm.warningInput}
              </span>
            ) : (
              ''
            )
          }
          <input type="tel" placeholder="Телефон"
                 ref={(el) => this.authLogin = el}
                 onBlur={() => this.validateNumber()}
          />
        </div>
        <button class='auth-login-form-btn'
                type='button'
                ref={(el) => this.authBtn = el}
                onClick={() => {
                  this.sendNumberHandler();
                }}
        >
          {this.logInForm.formBtnText}
        </button>
      </form>
    );
  }


  /**
   * вызывается предупреждение когда некоректно заполнен инпут
   * */
  public validateNumber() {
    // let phoneNumb = /^((8|\+7)[\- ]?)?(\(?\d{3}\)?[\- ]?)?[\d\- ]{7,10}$/;
    if (this.authLogin.value.length < 10) {
      this.authLogin.style.backgroundColor = '#ffe6e6!important';
      this.authLogin.style.borderColor = '#e54d4d!important';
      this.authBtn.setAttribute("disabled", "disabled");
      this.inputWarning = true;

      return false
    } else {
      this.authLogin.style.backgroundColor = 'white!important';
      this.authLogin.style.borderColor = '#dodgerblue!important';
      this.authBtn.removeAttribute("disabled");
      this.inputWarning = false;

      return true
    }
  }

  /**
   * при правильном запонение инпута меняет стейт
   * */
  public sendNumberHandler() {
    if (this.validateNumber() === true) {
      this.sendNumber.emit();
    }
  }
}
